/**
  ******************************************************************************
  * @file    External LED
  * @author  Lee Dyche - Tecsploit.com
  * @version V1.0.0
  * @date    25/04/2014
  * @brief   Controller for a simple 7 segment LED display, counts down from 10 when it hits zero sets pin D6 high to sound an
  * attached buzzer. Uses pins D5-D7 and B3-B7
  ******************************************************************************
  * @attention
  * This is program is provided as is with no warranty!!
  ******************************************************************************
  */


/* Includes ------------------------------------------------------------------*/
#include "stm32f4_discovery.h"


/* Private typedef -----------------------------------------------------------*/
GPIO_InitTypeDef  GPIO_InitStructure;


void Delay(__IO uint32_t nCount);
/* Private functions ---------------------------------------------------------*/


void DisplayNumber(int number);

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{

  /* GPIOD Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE);

  /* GPIOB Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOB, ENABLE);

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_3 | GPIO_Pin_4| GPIO_Pin_5| GPIO_Pin_6 | GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_7 | GPIO_Pin_5 | GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_Init(GPIOD, &GPIO_InitStructure);

  int number = 9;
  while (1)
  {
	  DisplayNumber(number);
	  number--;

	  if(number < 0)
		  number = 9;


	  /* Insert delay */
	  Delay(49999999);
  }
}



void DisplayNumber(int number){
	GPIO_ResetBits(GPIOB, GPIO_Pin_3 | GPIO_Pin_4| GPIO_Pin_5| GPIO_Pin_6 | GPIO_Pin_7);
	GPIO_ResetBits(GPIOD, GPIO_Pin_7 | GPIO_Pin_5 | GPIO_Pin_6 );

	switch(number){
		case 0:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			//GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);

			//this sets of the buzzer!
			GPIO_SetBits(GPIOD, GPIO_Pin_6);
			  Delay(49999999);
			  Delay(49999999);
		break;
		case 1:
			//GPIO_SetBits(GPIOB, GPIO_Pin_3);
			//GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			//GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			//GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 2:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			GPIO_SetBits(GPIOB, GPIO_Pin_5);
			//GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			//GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 3:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			//GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 4:
			//GPIO_SetBits(GPIOB, GPIO_Pin_3);
			//GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 5:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			//GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 6:
			//GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			//GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 7:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			//GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			//GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			//GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 8:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;
		case 9:
			GPIO_SetBits(GPIOB, GPIO_Pin_3);
			GPIO_SetBits(GPIOB, GPIO_Pin_4);
			//GPIO_SetBits(GPIOB, GPIO_Pin_5);
			GPIO_SetBits(GPIOB, GPIO_Pin_6);
			GPIO_SetBits(GPIOB, GPIO_Pin_7);

			GPIO_SetBits(GPIOD, GPIO_Pin_7);
			GPIO_SetBits(GPIOD, GPIO_Pin_5);
		break;


	}
}

/**
  * @brief  Delay Function.
  * @param  nCount:specifies the Delay time length.
  * @retval None
  */
void Delay(__IO uint32_t nCount)
{
  while(nCount--)
  {
  }
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */

/**
  * @}
  */

